@@ -14,13 +14,20 @@ pub fn file_exists(path: &str) -> bool
     Path::new(path).is_file()
 }
 
-/// Return the smallest part
+/// Return the last segment of a path
 pub fn basename(path: &str) -> String
 {
     let pieces: Vec<&str> = path.split('/').collect();
     pieces[pieces.len() - 1].to_string()
 }
 
+/// Return the first segments of a path
+pub fn dirname(path: &str) -> String
+{
+    let pieces: Vec<&str> = path.split('/').collect();
+    pieces[0..pieces.len()-1].join("/")
+}
+
 /// Write `data` to `path`
 pub fn write_to_file(path: &str, data: &str)
 {
@@ -49,3 +56,12 @@ pub fn mkdir(path: &str)
 {
     std::fs::create_dir_all(path).expect("Wasn't able to create directory:")
 }
+
+/// List all subdirectories in the specified directory
+pub fn list_subdirectories(dir: &str) -> Vec<String>
+{
+    glob(&format!("{}/*/", dir))
+        .expect("failed to read directory")
+        .map(|f| f.unwrap().to_string_lossy().to_string())
+        .collect()
+}
